/*=================================================================================
* Copyright (C) 2023 Electronic Technology Corp.
*
* MODULE      : HK OEM Printer Status Monitor
* AUTHOR      : Murphy Shu
* Serial ID   : XXXXXX
* DATE        : Sep , 2023
* DIRECTORY   : \XX\XXXX
* DESCRIPTION : To get the information form XML data for printer status monitor using
*==================================================================================*/

#ifndef HKSMIF_H
#define HKSMIF_H

/*------------------------ Architecture Dependence Definition ---------------------*/

/*------------------------ Engineering Tracing Definition -------------------------*/

/*------------------------ Compiler Dependence Definition ------------------------*/

/*------------------------ Macro (type) Definition -------------------------------*/

//The Data type definition for GUI/Printer-Panel menu selection 
#define GetPrinterInfo_ListTypeData                         1
#define GetPrinterInfo_IntegerTypeData                      2
#define GetPrinterInfo_ConstTypeData                        3
#define GetPrinterInfo_ButtonTypeData                       4

//The Printer Menu Operation definition for GUI/Printer-Panel operation
#define GetPrinterInfo_SystemMenu_Operation                 1
#define GetPrinterInfo_EcoMenu_Operation                    2
#define GetPrinterInfo_InputTrayMenu_Operation              3
#define GetPrinterInfo_PrinterMenu_Operation                4
#define GetPrinterInfo_NetworkMenu_Operation                5
#define GetPrinterInfo_PrintMenu_Operation                  6

//The definition Of Printer Status
#define GetPrinterInfo_DisconnectOrUnknow_Status            0x00
#define GetPrinterInfo_AttentionRequired_Status             0x01 // "Please check the printer for any problems
#define GetPrinterInfo_Offline_Status                       0x02
#define GetPrinterInfo_Warmingup_Status                     0x03
#define GetPrinterInfo_OnLineReadyToPrint_Status            0x04
#define GetPrinterInfo_Printing_Status                      0x05
#define GetPrinterInfo_PowerSave_Status                     0x06
#define GetPrinterInfo_LowPaperInAnyTray_Status             0x07
#define GetPrinterInfo_PaperEmptyInAnyTray_Status           0x08
#define GetPrinterInfo_LowToner_Status                      0x09
#define GetPrinterInfo_TonerEmpty_Status                    0x0A
#define GetPrinterInfo_DoorOpen_Status                      0x0B
#define GetPrinterInfo_SuppliesNotInstalled_Status          0x0C
#define GetPrinterInfo_CallService_Status                   0x0D
#define GetPrinterInfo_InputTrayNotInstalled_Status         0x0E
#define GetPrinterInfo_OutputBinAlmostFull_Status           0x0F
#define GetPrinterInfo_OutputBinFull_Status                 0x10
#define GetPrinterInfo_PrintingJobHeldByLoadPaper_Status    0x11
#define GetPrinterInfo_LoadPaperFromManualFeeder_Status     0x12
#define GetPrinterInfo_PaperEmptyInManualFeeder_Status      0x13
#define GetPrinterInfo_PaperJamOrEmpty_Status               0x14
#define GetPrinterInfo_PaperMismatch_Status                 0x15
#define GetPrinterInfo_PaperError_Status                    0x16
#define GetPrinterInfo_TrayError_Status                     0x17
#define GetPrinterInfo_TonerInvalid_Status                  0x18
#define GetPrinterInfo_TonerError_Status                    0x19
#define GetPrinterInfo_TonerFailure_Status                  0x1A
#define GetPrinterInfo_ImagingUnitFailure_Status            0x1B
#define GetPrinterInfo_PaperJam_Status                      0x1C
#define GetPrinterInfo_PaperJamAtManualFeeder_Status        0x1D
#define GetPrinterInfo_PaperJamAtTray1_Status               0x1E
#define GetPrinterInfo_JamAtInside_Status                   0x1F
#define GetPrinterInfo_JamAtExitArea_Status                 0x20
#define GetPrinterInfo_JamAtDuplexBottom_Status             0x21
#define GetPrinterInfo_JamAtDuplexTop_Status                0x22
#define GetPrinterInfo_JamAtDuplexPath_Status               0x23
#define GetPrinterInfo_ImagingUnitError_Status              0x24
#define GetPrinterInfo_ImagingUnitWarning_Status            0x25
#define GetPrinterInfo_TransbeltError_Status                0x26
#define GetPrinterInfo_TransbeltWarning_Status              0x27
#define GetPrinterInfo_FinisherError_Status                 0x28
#define GetPrinterInfo_WasteTankFull_Status                 0x29
#define GetPrinterInfo_FuserError_Status                    0x2A
#define GetPrinterInfo_LSUError_Status                      0x2B
#define GetPrinterInfo_SystemError_Status                   0x2C
#define GetPrinterInfo_SystemErrorCallService_Status        0x2D
#define GetPrinterInfo_GeneralErrorOrWarning_Status         0x2E
#define GetPrinterInfo_ImagingUnitShouldReplace_Status      0x2F
#define GetPrinterInfo_MaxStatusCodeID_Number               0x30

//The definitional of Timeout Value (MS) for Network printer state or status getting
//If the timeout value is smaller, due to network bandwidth or speed issues, maybe can not get wanted state or status.
#define GetPrinterInfo_VeryFastTimeoutValue                 100 //100MS
#define GetPrinterInfo_FastTimeoutValue                     500 //500MS
#define GetPrinterInfo_NormalTimeoutValue                   1000 //1000MS, we recommend caller use this value is better
#define GetPrinterInfo_SlowTimeoutValue                     1500 //1500MS
#define GetPrinterInfo_VerySlowTimeoutValue                 2000 //2000MS

/*------------------------ Common Structure Definition ---------------------------*/

//The Current Printer Setting Data Structure Definition for Caller Use to update the printer menu setting
typedef struct getprinterinfo_printerSettingData_S {
	unsigned char                                           dataType; //Should same as the definition of getprinterinfo_menuConfigurationParms_Type
	unsigned char                                           *name; //Should same as the definition of getprinterinfo_menuConfigurationParms_Type
	unsigned char                                           *compactName; //Should same as the definition of getprinterinfo_menuConfigurationParms_Type
	union {
		long                            integerValue; //Only for GetPrinterInfo_IntegerTypeData
		unsigned char                   *stringValue; //For GetPrinterInfo_ListTypeData / GetPrinterInfo_ConstTypeData / GetPrinterInfo_ButtonTypeData
	}                                                       currentSetting;
} getprinterinfo_printerSettingData_Type;

typedef struct getprinterinfo_listTypeDataValue_S {
	unsigned char                                           valueNumber;
	unsigned char                                           **valueList;
	unsigned char                                           *currentValue;
	unsigned char                                           *defaultValue;
} getprinterinfo_listTypeDataValue_Type;

typedef struct getprinterinfo_integerTypeDataValue_S {
	long                                                    minValue;
	long                                                    maxValue;
	long                                                    currentValue;
	long                                                    defaultValue;
} getprinterinfo_integerTypeDataValue_Type;

typedef struct getprinterinfo_constTypeDataValue_S {
	unsigned char                                           *currentValue;
} getprinterinfo_constTypeDataValue_Type;

typedef struct getprinterinfo_buttonTypeDataValue_S {
	unsigned char                                           *pressString;
} getprinterinfo_buttonTypeDataValue_Type;

typedef struct getprinterinfo_menuConfigurationParms_S {
	unsigned char                                           dataType; //Only List, Integer, Const, Button
	unsigned char                                           *name;
	unsigned char                                           *compactName;
	union {
		getprinterinfo_listTypeDataValue_Type        *listData;
		getprinterinfo_integerTypeDataValue_Type     *integerData;
		getprinterinfo_constTypeDataValue_Type       *constData;
		getprinterinfo_buttonTypeDataValue_Type      *buttonData;
	}  dataValue;
	struct getprinterinfo_menuConfigurationParms_S          *next;
} getprinterinfo_menuConfigurationParms_Type;

//The Definition Of USB Printer State Parameters
typedef struct getprinterinfo_usbPrinterStateParms_S {
	unsigned char                                           isMFP; //If it is MFP, then will be 1, else it is 0 means SFP, 
	unsigned char                                           isMono; //If it is a Mono printer, then will be 1, else it is 0 means Color printer
	unsigned char                                           supportNetwork; //If support Network, then it will be 1, else it is 0 means Not-Support or Unknow
	unsigned char                                           *hostName; //Only have meaning when printer support Network
	unsigned char                                           *ipV4Address; //Only have meaning when printer support Network
	unsigned char                                           *subnetMask; //Only have meaning when printer support Network
	unsigned char                                           *gatewayAddress; //Only have meaning when printer support Network
	unsigned char                                           *usbDevicePortPath;
	unsigned char                                           *modelName;
	void                                                    *privatedParms;
} getprinterinfo_usbPrinterStateParms_Type;

//The Network Printer Information Structure Definition for Called Using
typedef struct getprinterinfo_networkPrinterInformationParms_S {
	unsigned char                                           *ipV4Address;
	unsigned char                                           *modelName;
	unsigned char                                           *hostName;
} getprinterinfo_networkPrinterInformationParms_Type;

//The Definition Of Network Printer State Parameters 网络打印机信息的结构体
typedef struct getprinterinfo_networkPrinterStateParms_S {
	unsigned char                                           isMFP; //If it is MFP, then will be 1, else it is 0 means SFP, 
	unsigned char                                           isMono; //If it is a Mono printer, then will be 1, else it is 0 means Color printer
	getprinterinfo_networkPrinterInformationParms_Type      infoParms;
	void                                                    *privatedParms;
} getprinterinfo_networkPrinterStateParms_Type;

//The Definition Callback Procedure which To Inform Caller The Found Network Printer, caller only could get the information and can NOT release the passed information parameter
typedef void (*GetNetworkPrinter_CallbackProc)(getprinterinfo_networkPrinterInformationParms_Type *);

//The Definition Callback Procedure which To Inform Caller The Found USB Printer, and the passed USB printer state should be kept by caller, and released by caller
typedef void (*GetUSBPrinter_CallbackProc)(getprinterinfo_usbPrinterStateParms_Type *);

//====================================================================================

//原先 USB打印机的链表
typedef struct usableUSBPrinterList_S {
    getprinterinfo_usbPrinterStateParms_Type  *usbPrinterState;
    unsigned char                               isUSB;
    struct usableUSBPrinterList_S             *next;
} usableUSBPrinterList_Type;
extern usableUSBPrinterList_Type                    *currentUSBPrinterList ;
extern usableUSBPrinterList_Type * curUsbPL;

//USB打印机回调函数
extern void getUSBPrinter_CallbackProc(getprinterinfo_usbPrinterStateParms_Type *usbPrinterState);
//找到的USB打印机个数
extern unsigned long                       currentFoundUSBPrinterNumber;

//原先 网络打印机的链表
 typedef struct usableNetworkPrinterList_S {
    getprinterinfo_networkPrinterStateParms_Type  *networkPrinterState;
     unsigned char                                ipAddress[20];
     struct usableNetworkPrinterList_S            *next;
     int                                       USBorNET;
 } usableNetworkPrinterList_Type;
extern usableNetworkPrinterList_Type                     *currentNetworkPrinterList ;

extern getprinterinfo_networkPrinterStateParms_Type *networkPrinterState;

//网络打印机回调函数
extern void getNetworkPrinter_CallbackProc(getprinterinfo_networkPrinterInformationParms_Type *networkPrinterInfo);
extern void getNetworkPrinter_CallbackProcManage(getprinterinfo_networkPrinterInformationParms_Type *networkPrinterInfo);//用于打印机管理界面判断上一次保存的打印机信息是否存在
//窗口居中函数
extern void centWidget(QWidget *widget);
//一个链表包含有共用体存放两种类型打印机的信息
typedef struct printerStateParms_S {
    unsigned char     isUSB;
    union {
        getprinterinfo_usbPrinterStateParms_Type   *usbState;
        getprinterinfo_networkPrinterStateParms_Type   *networkState;//网络打印机信息的结构体
    }  printerState;
    struct printerStateParms_S     *next;
}    printerStateParms_Type;
extern printerStateParms_Type *printerStateParamsList;

//====================================================================================

#ifdef WIN32 //For Window

//The following defination for DLL calling 

//Search The Network printers automatically or specified IP address segement
typedef void (*SearchNetworkPrinters)(GetNetworkPrinter_CallbackProc , unsigned char * , unsigned char * , long , long , unsigned int);

//Cancel the searching operation for Network printers 
typedef void (*CancelSearchNetworkPrinters)(void);

//The procedure to prepare the network printer state for coming operation, it should be done at beginning
typedef getprinterinfo_networkPrinterStateParms_Type *(*PrepareNetworkPrinterState)(unsigned char * , unsigned int);

//The procedure to release the prepared network printer state, it should be done at ending
typedef void (*ReleaseNetworkPrinterState)(getprinterinfo_networkPrinterStateParms_Type *);

//Get the current network printer status by specified IP address
typedef unsigned char (*GetNetworkPrinterStatus)(getprinterinfo_networkPrinterStateParms_Type * , unsigned char ** , unsigned int);

//Get the network printer toner status includes toner number and usable level
typedef unsigned char (*GetNetworkPrinterCurrentTonerState)(getprinterinfo_networkPrinterStateParms_Type * , unsigned char * , unsigned char ** , unsigned char ** , unsigned int);

//Get the network printer tray-N and Manual-Feeder state includes paper size and paper type
typedef unsigned char (*GetNetworkPrinterTrayNState)(getprinterinfo_networkPrinterStateParms_Type * , unsigned char , unsigned char * , unsigned char * , int);

//Get the network printer picture data which used for caller to display on UI
typedef unsigned long (*GetNetworkPrinterPictureData)(getprinterinfo_networkPrinterStateParms_Type * , unsigned char **);

//Get the network printer serial number and FW version information which used for caller
typedef unsigned char (*GetNetworkPrinterSNAndFWInfo)(getprinterinfo_networkPrinterStateParms_Type * , unsigned char ** , unsigned char **);

//Get the network printer total printed papers
typedef unsigned long (*GetNetworkPrinterTotalPrintedPapers)(getprinterinfo_networkPrinterStateParms_Type *);

//The following procedure just used for USB printer accessing operation
//Find out all USB printers automatically, 
typedef void (*SearchUSBPrinters)(GetUSBPrinter_CallbackProc , unsigned char *);

//The procedure to release the prepared USB printer state, it should be done at ending
typedef void (*ReleaseUSBPrinterState)(getprinterinfo_usbPrinterStateParms_Type *);

//Get the current USB printer status
typedef unsigned char (*GetCurrentUSBPrinterStatus)(getprinterinfo_usbPrinterStateParms_Type * , unsigned char **);

//Get the USB printer toner status
typedef unsigned char (*GetCurrentUSBPrinterTonerState)(getprinterinfo_usbPrinterStateParms_Type * , unsigned char * , unsigned char ** , unsigned char **);

//Get the USB printer tray-N and Manual-Feeder state
typedef unsigned char (*GetCurrentUSBPrinterTrayNState)(getprinterinfo_usbPrinterStateParms_Type * , unsigned char , unsigned char * , unsigned char *);

//Get the USB printer picture data which used for caller to display on UI
typedef unsigned long (*GetCurrentUSBPrinterPictureData)(getprinterinfo_usbPrinterStateParms_Type * , unsigned char **);

//Get the USB printer serial number and FW version information which used for caller
typedef unsigned char (*GetCurrentUSBPrinterSNAndFWInfo)(getprinterinfo_usbPrinterStateParms_Type * , unsigned char ** , unsigned char **);

//Get the USB printer current configuration only when enter the USB printer setting or reflush the USB printer state
//Note, this procedure SHOULD NOT be execuated frequently, especially when USB printer just in working phase, 
//      otherwise you may not get correct result, or may break the USB communication of printer.
typedef unsigned char (*GetCurrentUSBPrinterCurrentConfiguration)(getprinterinfo_usbPrinterStateParms_Type *);

//Release the created Menu configuration list 
typedef void (*ReleaseMenuConfigurationParms)(getprinterinfo_menuConfigurationParms_Type *);

//Get the current USB printer menu configuration which used for caller
typedef getprinterinfo_menuConfigurationParms_Type *(*GetCurrentMenuConfiguration)(getprinterinfo_usbPrinterStateParms_Type * , unsigned char);

//Update the current setting base on given setting parameters for specified menu items
typedef unsigned char (*UpdateCurrentUSBPrinterSetting)(getprinterinfo_usbPrinterStateParms_Type * , unsigned char , unsigned char , getprinterinfo_printerSettingData_Type *);

//Initial and create the working state for USB printer operation
typedef unsigned char (*InitialUSBPrinterState)(void);

//Kill the working state after all USB printer operation completed
typedef void (*KillUSBState)(void);

//Enabled or Disable the Execuation-Log be printed out
typedef void (*PrintExecuationLog)(unsigned char);

//Whether it is our wanted USB printer
typedef unsigned char (*IsWantedUSBPrinter)(getprinterinfo_usbPrinterStateParms_Type * , unsigned char * , unsigned short , unsigned short);

//Update the IPv4 address for specified USB printer
typedef void (*UpdateUSBPrinterIPv4Address)(getprinterinfo_usbPrinterStateParms_Type * , unsigned char , unsigned char * , unsigned char * , unsigned char *);

#else //For Linux

//Search The Network printers automatically or specified IP address segement
extern void SearchNetworkPrinters(GetNetworkPrinter_CallbackProc , unsigned char * , unsigned char * , long , long , unsigned int);

//Cancel the searching operation for Network printers 
extern void CancelSearchNetworkPrinters(void);

//The procedure to prepare the network printer state for coming operation, it should be done at beginning
extern getprinterinfo_networkPrinterStateParms_Type *PrepareNetworkPrinterState(unsigned char * , unsigned int);

//The procedure to release the prepared network printer state, it should be done at ending
extern void ReleaseNetworkPrinterState(getprinterinfo_networkPrinterStateParms_Type *);

//Get the current network printer status by specified IP address
extern unsigned char GetNetworkPrinterStatus(getprinterinfo_networkPrinterStateParms_Type * , unsigned char ** , unsigned int);

//Get the network printer toner status includes toner number and usable level
extern unsigned char GetNetworkPrinterCurrentTonerState(getprinterinfo_networkPrinterStateParms_Type * , unsigned char * , unsigned char ** , unsigned char ** , unsigned int);

//Get the network printer tray-N and Manual-Feeder state includes paper size and paper type
extern unsigned char GetNetworkPrinterTrayNState(getprinterinfo_networkPrinterStateParms_Type * , unsigned char , unsigned char * , unsigned char * , int);

//Get the network printer picture data which used for caller to display on UI
extern unsigned long GetNetworkPrinterPictureData(getprinterinfo_networkPrinterStateParms_Type * , unsigned char **);

//Get the network printer serial number and FW version information which used for caller
extern unsigned char GetNetworkPrinterSNAndFWInfo(getprinterinfo_networkPrinterStateParms_Type * , unsigned char ** , unsigned char **);

//Get the network printer total printed papers
extern unsigned long GetNetworkPrinterTotalPrintedPapers(getprinterinfo_networkPrinterStateParms_Type *);

//The following procedure just used for USB printer accessing operation
//Find out all USB printers automatically, 
extern void SearchUSBPrinters(GetUSBPrinter_CallbackProc , unsigned char *);

//The procedure to release the prepared USB printer state, it should be done at ending
extern void ReleaseUSBPrinterState(getprinterinfo_usbPrinterStateParms_Type *);

//Get the current USB printer status
extern unsigned char GetCurrentUSBPrinterStatus(getprinterinfo_usbPrinterStateParms_Type * , unsigned char **);

//Get the USB printer toner status
extern unsigned char GetCurrentUSBPrinterTonerState(getprinterinfo_usbPrinterStateParms_Type * , unsigned char * , unsigned char ** , unsigned char **);

//Get the USB printer tray-N and Manual-Feeder state
extern unsigned char GetCurrentUSBPrinterTrayNState(getprinterinfo_usbPrinterStateParms_Type * , unsigned char , unsigned char * , unsigned char *);

//Get the USB printer picture data which used for caller to display on UI
extern unsigned long GetCurrentUSBPrinterPictureData(getprinterinfo_usbPrinterStateParms_Type * , unsigned char **);

//Get the USB printer serial number and FW version information which used for caller
extern unsigned char GetCurrentUSBPrinterSNAndFWInfo(getprinterinfo_usbPrinterStateParms_Type * , unsigned char ** , unsigned char **);

//Get the USB printer current configuration only when enter the USB printer setting or reflush the USB printer state
//Note, this procedure SHOULD NOT be execuated frequently, especially when USB printer just in working phase, 
//      otherwise you may not get correct result, or may break the USB communication of printer.
extern unsigned char GetCurrentUSBPrinterCurrentConfiguration(getprinterinfo_usbPrinterStateParms_Type *);

//Release the created Menu configuration list 
extern void ReleaseMenuConfigurationParms(getprinterinfo_menuConfigurationParms_Type *);

//Get the current USB printer menu configuration which used for caller
extern getprinterinfo_menuConfigurationParms_Type *GetCurrentMenuConfiguration(getprinterinfo_usbPrinterStateParms_Type * , unsigned char);

//Update the current setting base on given setting parameters for specified menu items
extern unsigned char UpdateCurrentUSBPrinterSetting(getprinterinfo_usbPrinterStateParms_Type * , unsigned char , unsigned char , getprinterinfo_printerSettingData_Type *);

//Initial and create the working state for USB printer operation
extern unsigned char InitialUSBPrinterState(void);

//Kill the working state after all USB printer operation completed
extern void KillUSBState(void);

//Enabled or Disable the Execuation-Log be printed out
extern void PrintExecuationLog(unsigned char);

//Whether it is our wanted USB printer
extern unsigned char IsWantedUSBPrinter(getprinterinfo_usbPrinterStateParms_Type * , unsigned char * , unsigned short , unsigned short);

//Update the IPv4 address for specified USB printer
extern void UpdateUSBPrinterIPv4Address(getprinterinfo_usbPrinterStateParms_Type * , unsigned char , unsigned char * , unsigned char * , unsigned char *);

#endif

/*------------------------ Variable Definition -----------------------------------*/

//Define the Staus Display Message, this table should compared with "The definition Of Printer Status" defined above
/* Following are display message on GUI
	"Printer Disconnect By USB/Ethernet Or Unknow", //GetPrinterInfo_DisconnectOrUnknow_Status
	"Please Check Printer For Any Problems", //GetPrinterInfo_AttentionRequired_Status
	"Offline", //GetPrinterInfo_Offline_Status
	"Warming Up", //GetPrinterInfo_Warmingup_Status
	"Ready", //GetPrinterInfo_OnLineReadyToPrint_Status
	"Printing", //GetPrinterInfo_Printing_Status
	"Power Save", //GetPrinterInfo_PowerSave_Status
	"All Trays Low Paper", //GetPrinterInfo_LowPaperInAnyTray_Status
	"All Trays Paper Empty", //GetPrinterInfo_PaperEmptyInAnyTray_Status
	"Toner Lower", //GetPrinterInfo_LowToner_Status
	"Toner Empty", //GetPrinterInfo_TonerEmpty_Status
	"Cover Open", //GetPrinterInfo_DoorOpen_Status
	"Toner/Drum/Fuser Etc. Not Installed", //GetPrinterInfo_SuppliesNotInstalled_Status
	"Fatal Error Call Service", //GetPrinterInfo_CallService_Status
	"Input Tray Not Installed", //GetPrinterInfo_InputTrayNotInstalled_Status
	"Output Bin Almost Full", //GetPrinterInfo_OutputBinAlmostFull_Status
	"Output Bin Full", //GetPrinterInfo_OutputBinFull_Status
	"Printing Paused Due To Load Paper", //GetPrinterInfo_PrintingJobHeldByLoadPaper_Status
	"Load Paper From Manual Feeder", //GetPrinterInfo_LoadPaperFromManualFeeder_Status
	"Manual Feeder No Paper", //GetPrinterInfo_PaperEmptyInManualFeeder_Status
	"Paper Jam Or Paper Empty", //GetPrinterInfo_PaperJamOrEmpty_Status
	"Paper Mismatch", //GetPrinterInfo_PaperMismatch_Status
	"Paper Error", //GetPrinterInfo_PaperError_Status
	"Input Tray Error", //GetPrinterInfo_TrayError_Status
	"Toner Invalid", //GetPrinterInfo_TonerInvalid_Status
	"Toner Error", //GetPrinterInfo_TonerError_Status
	"Toner Failure", //GetPrinterInfo_TonerFailure_Status
	"Imaging Unit Faulure", //GetPrinterInfo_ImagingUnitFailure_Status
	"Paper Jam", //GetPrinterInfo_PaperJam_Status
	"Paper Jam At Manual Feeder", //GetPrinterInfo_PaperJamAtManualFeeder_Status
	"Paper Jam At Input Tray-1", //GetPrinterInfo_PaperJamAtTray1_Status
	"Paper Jam Inside Printer", //GetPrinterInfo_JamAtInside_Status
	"Paper Jam At Exit Area", //GetPrinterInfo_JamAtExitArea_Status
	"Paper Jam At Bottom Of Duplex Path", //GetPrinterInfo_JamAtDuplexBottom_Status
	"Paper Jam At Top Of Duplex Path", //GetPrinterInfo_JamAtDuplexTop_Status
	"Paper Jam Inside Duplex Path", //GetPrinterInfo_JamAtDuplexPath_Status
	"Imaging Unit Is Not Compatible", //GetPrinterInfo_ImagingUnitError_Status
	"Imaging Unit May Need Be Replaced", //GetPrinterInfo_ImagingUnitWarning_Status
	"Transfer Belt Not Installed Or May Need Be Replaced", //GetPrinterInfo_TransbeltError_Status
	"Transfer Belt Need Be Replaced", //GetPrinterInfo_TransbeltWarning_Status
	"Finisher Error", //GetPrinterInfo_FinisherError_Status
	"WasteTank Full And Should Be Replaced", //GetPrinterInfo_WasteTankFull_Status
	"Fuser Error", //GetPrinterInfo_FuserError_Status
	"LSU Error", //GetPrinterInfo_LSUError_Status
	"Printer System Error", //GetPrinterInfo_SystemError_Status
	"Printer System Error And Call Service", //GetPrinterInfo_SystemErrorCallService_Status
	"Printer Error Or Warning, Please Check", //GetPrinterInfo_GeneralErrorOrWarning_Status
	"Imaging Unit Should Be Replaced"  //GetPrinterInfo_ImagingUnitShouldReplace_Status
*/

/*------------------------ Functions Definition ----------------------------------*/


/*------------------------ Macro (Functions) Definition --------------------------*/

#endif /* HKSMIF_H */
